@@ -27,7 +27,7 @@ def get_lastest_file(dongle_id: str):
     bucket_name = 'creationlabs-raw-data'
     bucket = s3_resource.Bucket(bucket_name)
 
-    last_segment, last_complete_drive = get_selected_drives(None, s3_resource, bucket_name, dongle_id, 10)
+    last_segment, last_complete_drive = get_selected_drives(None, s3_resource, bucket_name, dongle_id)
     # 064b1a99381ec054 2021-09-09--16-31-00 
     drive = '--'.join(last_segment.drive.split('--')[:-1])
     return urlifier(last_segment.dongle_id, drive)
@@ -77,15 +77,14 @@ def get_selected_drives(s3, s3_resource, bucket_name, dongle_id):
     """
     df = get_drives_df(s3_resource, bucket_name, dongle_id)
     
-    if dongle_id=='064b1a99381ec054':
-        # import ipdb; ipdb.set_trace()
-        pass
-
     if len(df) == 0:
         print(f"No files found for {dongle_id}")
         # return two empty series of dimensions 14
         return pd.Series(), pd.Series()
 
+    # filter out playlist files/folders
+    df = df[df.drive_time.str.len() > 16 ]
+
     latest_drive = df.iloc[0]
     last_complete_drives = df[df.seg_num!=0]
 
@@ -134,11 +133,10 @@ def get_drives(target, bucket_name: str = 'creationlabs-raw-data', metadata_file
     else:
         df = get_drives_df(s3_resource, bucket_name, dongle_id=target, filter=filter)
 
-    # import ipdb; ipdb.set_trace()
-    df['upload_time'] = df.drive.str.split('--').str[:-1].str.join('--')
+    # TODO: fix unkown bug
+    df = df[df.drive_time.str.len() > 16 ]
 
-    # TODO: fix this
-    df = df[df.upload_time.str.len() > 16 ]
+    df['upload_time'] = df.drive.str.split('--').str[:-1].str.join('--')
     df['upload_time'] = pd.to_datetime(df.upload_time, format='%Y-%m-%d--%H-%M-%S')
 
     # get naturaltime from now to the time of the latest file
@@ -147,9 +145,10 @@ def get_drives(target, bucket_name: str = 'creationlabs-raw-data', metadata_file
 
 
     if target in ['0', '-1']:
-        df = add_metadata(df, metadata_file)
-        df = df[['dongle_id','drive','time','seg_num','Registration Number']]
-        print(df.head(show_n))
+        if filter: 
+            df = add_metadata(df, metadata_file)
+            print(df[['dongle_id','drive','time','seg_num','Registration Number']])
+        else: print(df[['dongle_id','drive','time','seg_num']])
     else:
         df['link'] = df.apply(lambda x: urlifier(x.dongle_id, x.drive_time), axis=1)
         df = df[['drive_time','seg_num','link']]
