@@ -20,7 +20,7 @@ def write_sftp(name: str, remote: str, ip: int,
         "username": user,
         "remotePath": remote,
         "privateKeyPath" : key_path,
-        "uploadOnSave": "true",
+        "uploadOnSave": True,
         "watcher": {
             "files": "*.{py,.sh,.txt}"
         },
@@ -37,7 +37,9 @@ def write_sftp(name: str, remote: str, ip: int,
     if not os.path.exists(sftp_path):
         os.mkdir(os.path.join(os.getcwd(), '.vscode'))
         # create sftp
-        json.dump(new_config, open(sftp_path, 'w'))
+        with open(sftp_path, 'w') as fp:
+            fp.write(json.dumps(new_config).replace("'", ""))
+        print(new_config)
 
     else:
         old_config = json.load(open(sftp_path, 'r'))
@@ -45,4 +47,7 @@ def write_sftp(name: str, remote: str, ip: int,
         config = {
             **new_config
         }
-        json.dump(config, open(sftp_path, 'w'))
\ No newline at end of file
+        with open(sftp_path, 'w') as fp:
+            fp.write(json.dumps(new_config).replace("'", ""))
+        print(new_config)
+        
